# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name="burst_statsd",
    version='0.1.2',
    zip_safe=False,
    platforms='any',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    install_requires=['statsd'],
    url="https://github.com/dantezhu/burst_statsd",
    license="MIT",
    author="dantezhu",
    author_email="zny2008@gmail.com",
    description="upload burst stat to statsd",
)



# -*- coding: utf-8 -*-
"""
读取gateway统计数据并解析
"""

import os
import re
import json


class StatReader(object):

    cmd = None

    def __init__(self, cmd):
        """
        :param cmd: 工具文件的路径
        :return:
        """

        self.cmd = cmd

    def read(self):
        """
        读取一次
        :return:
        """

        output = os.popen(self.cmd).read()
        str_json = re.search(r'{.*}', output, re.S).group()

        return json.loads(str_json)
